@@ -21,12 +21,10 @@ use Path::Tiny;
 
 my $logger = get_logger("Backend::Dpkg::Patch");
 
-sub skip_open { 1;}
+sub skip_open { return 1;}
 
 # TODO: use a role provided by Config::Model
-sub cfg_path {
-    my $self = shift;
-    my %args = @_;
+sub cfg_path ($self, %args) {
     my $cfg_dir   = $args{config_dir};
     my $dir
         = $args{root}   ? path($args{root})->child($cfg_dir)
@@ -35,10 +33,7 @@ sub cfg_path {
     return $dir;
 }
 
-sub read {
-    my $self = shift;
-    my %args = @_;
-
+sub read ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object
     # root       => './my_test',  # fake root directory, userd for tests
@@ -77,6 +72,9 @@ sub read {
     }
     chomp @$header;
 
+    # remove last blank line (added back by writer)
+    pop @$header if $header->@* and $header->[-1] =~ /^\s*$/;
+
     my $c = [] ;
     $logger->trace("header: @$header") ;
     my %stuff ;
@@ -107,8 +105,8 @@ sub read {
           if @$c > 4; # $c contains [ line_nb, section_ref ]
     }
 
-    my $description_holder;
     my @description_text ;
+    my $synopsis_in_subject = 0;
     while (@$c) {
         my ( $section_line, $section ) = splice @$c, 0, 2;
         foreach ( my $i = 0 ; $i < $#$section ; $i += 2 ) {
@@ -117,11 +115,24 @@ sub read {
             if ( my $found = $node->find_element( $key, case => 'any' ) ) {
                 my $elt = $found ;
                 my $to_store = $v_ref;
-                if ($found =~ /^Subject|Description$/) {
-                    $description_holder = $found;
-                    $elt = 'Synopsis';
-                    $to_store = [ shift $v_ref->@* ];
-                    push @description_text, $v_ref->@*;
+                if ($found eq 'Subject') {
+                    # here Synopsis is Subject. DEP-3 does not allow multi line
+                    # Subject. This will be cleaned up while storing the value
+                    $to_store = [ $v_ref->@* ];
+                    $synopsis_in_subject = 1;
+                }
+                elsif ($found eq 'Description') {
+                    if ($synopsis_in_subject) {
+                        push @description_text, $v_ref->@*;
+                        next;
+                    }
+                    else {
+                        # here Synopsis is the first line of
+                        # Description.
+                        $elt = 'Synopsis';
+                        $to_store = [ shift $v_ref->@* ];
+                        push @description_text, $v_ref->@*;
+                    }
                 }
 
                 my $elt_obj = $node->fetch_element($elt);
@@ -144,8 +155,7 @@ sub read {
     # add salvaged lines in the order they were found
     push @description_text, map { [$stuff{$_}, $_, ''] } sort { $a <=> $b ;} keys %stuff ;
 
-    $description_holder //= 'Description';
-    my $elt_obj = $node->fetch_element($description_holder);
+    my $elt_obj = $node->fetch_element('Description');
     $self->store_section_leaf_element ( $logger, $elt_obj, $check, \@description_text);
 
     # at last, save the "meat" of the patch
@@ -154,10 +164,7 @@ sub read {
     return 1;
 }
 
-sub write {
-    my $self = shift;
-    my %args = @_;
-
+sub write ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object
     # root       => './my_test',  # fake root directory, userd for tests
@@ -172,29 +179,26 @@ sub write {
     $logger->info("Writing patch $patch_file");
     my $res = '';
 
-    # first: write Description or Subject (where the subuject body is written
-    # outside the structured part -- as required by dep-3)
     my $synopsis         = $node->fetch_element_value('Synopsis') || "";
     my $description_body = $node->fetch_element_value('Description') ;
     my $subject_body     = $node->fetch_element_value('Subject') ;
 
-    if ($description_body and $subject_body) {
-        die "Write error: cannot have both Subject body and description body";
+    # first: write Description or Subject (where the subject body is written
+    # outside the structured text)
+    my $outside_text = '';
+    if ($subject_body) {
+        $res .= "Subject: ";
+        $res .= $self->write_dpkg_text($subject_body) ;
+        $outside_text .= "$synopsis\n" if $synopsis;
+        $outside_text .= "$description_body\n" if $description_body;
     }
     elsif ($description_body) {
         my $to_write = $synopsis . "\n" . $description_body ;
         $res .= "Description: ";
         $res .= $self->write_dpkg_text($to_write) ;
     }
-    elsif ($subject_body) {
-        # DEP-3: When Subject is used, it is expected that the
-        # long description is outside of the structured
-        # fields.
-        $res .= "Subject: ";
-        $res .= $self->write_dpkg_text($synopsis) ;
-    }
     else {
-        # no description body, write only synopsis
+        # no description body, write only synopsis in Description
         $res .= "Description: ";
         $res .= $self->write_dpkg_text($synopsis) ;
     }
@@ -218,9 +222,9 @@ sub write {
         }
     }
 
-    # third: write subect body
-    if ($subject_body) {
-        $res .= $subject_body."\n";
+    # third: write long description outside of structured fields
+    if ($outside_text) {
+        $res .= "\n$outside_text\n";
     }
 
     $res .= $node->fetch_element_value('diff');
@@ -250,7 +254,9 @@ All C<Patch> files keyword are read in a case-insensitive manner.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'Dpkg::Patch' ) ;
+=head2 new
+
+Parameters: C<< node => $node_obj, name => 'Dpkg::Patch' >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
