@@ -12,9 +12,8 @@ use 5.20.0;
 use feature qw/postderef signatures/;
 no warnings qw/experimental::postderef experimental::signatures/;
 
-use base qw/Config::Model::Backend::Any/;
-
-my $logger = get_logger("Backend::DpkgSyntax") ;
+my $logger = get_logger("Backend.Dpkg.Syntax") ;
+my $user_logger = get_logger('User');
 
 sub parse_dpkg_file {
     my $self = shift ;
@@ -47,14 +46,15 @@ sub parse_dpkg_lines {
     
     # list of list ( $line_nb_nb, section, ... ) where section is
     # [keyword,[ maybe keyword comments, .. , [ value, line_nb, altered , comment ] , ... ])
-    my @res ; 
-    
+    my @res ;
+
     foreach my $l (@$lines) {
         $logger->trace("Parsing $file_path line $line_nb '$l'");
         if ( $l =~ /^#/) { # comment are always located before the keyword (hopefully)
             if ($comment_allowed) {
                 my $c = $l ;
-                $c =~ s/#\s// ;
+                $c =~ s/#// ;
+                $logger->trace("line $line_nb is comment '$l'");
                 push @comments, $c ;
             }
             else {
@@ -64,12 +64,10 @@ sub parse_dpkg_lines {
                     parsed_line => $line_nb,
                     message => "Comments are not allowed. (use -force option to drop comments)",
                 ) if $check eq 'yes' ;
-                my $msg = "File $file_path: Dropped comment line $line_nb";
-                $logger->error($msg) if $check eq 'skip';
-                $logger->warn($msg) if $check eq 'no';
+                $user_logger->warn("File $file_path: Dropped comment line $line_nb");
             }
         }
-        elsif ( $l =~ /^([\w\-]+)\s*:/ ) {  # keyword:
+        elsif ( $l =~ m{^([\w\-]+)\s*:(?!//)} ) {  # keyword: but not http://
             my ($field,$text) = split /\s*:\s*/,$l,2 ;
             $text =~ s/\s+$//;
             $key = $field ;
@@ -97,9 +95,9 @@ sub parse_dpkg_lines {
         } 
         elsif ( $l =~ /^\s+\.$/) {   # line with a single dot
             $logger->trace("dot line: adding blank line to field $key");
-            _store_line_and_comments($store_list_ref,$file_path,"",$check,$line_nb, $handle_garbage, \@comments) ;
+            _store_line_and_comments($store_list_ref,$file_path,".",$check,$line_nb, $handle_garbage, \@comments) ;
         }
-        elsif ( $l =~ s/^\s//) {     # non empty line
+        elsif ( $l =~ /^\s/) {     # non empty line
             $logger->trace("text line: adding '$l' to field $key");
             _store_line_and_comments($store_list_ref,$file_path,$l , $check,$line_nb, $handle_garbage, \@comments);
         }
@@ -153,6 +151,7 @@ sub parse_dpkg_lines {
 sub _store_line_and_comments ($store_ref,$file_path,$line,$check,$line_nb, $handle_garbage, $comments) {
 
     if (defined $store_ref) {
+        substr $line,0,1,''; # remove first char which shows field continuation
         push $store_ref->@* , [ $line , $line_nb, '', $comments->@* ]
     }
     elsif ($handle_garbage) {
@@ -169,6 +168,7 @@ sub _store_line_and_comments ($store_ref,$file_path,$line,$check,$line_nb, $hand
         $logger->error($msg) if $check eq 'skip';
     }
     $comments->@* = (); # reset comments, they are now stored
+    return;
 }
 
 # input is [ section [ keyword => value | value_list_ref ] ]
@@ -277,7 +277,7 @@ sub node_to_section ($self, $node, $elt_list = [ $node->get_element_names ]) {
         my $elt_obj = $node->fetch_element($elt) ;
 
         my $c = $elt_obj->annotation ;
-        push @section, map {'# '.$_} split /\n/,$c if $c ;
+        push @section, map {'#'.$_} split /\n/,$c if $c ;
 
         if ($type eq 'hash') {
             die "package_spec: unexpected hash type in ".$node->name." element $elt\n" ;
@@ -292,7 +292,7 @@ sub node_to_section ($self, $node, $elt_list = [ $node->get_element_names ]) {
                 next unless defined $value;
 
                 my $note = $value_obj->annotation;
-                my $comment = $note ? join ("\n",map {'# '.$_} split /\n/,$note ) : undef;
+                my $comment = $note ? join ("\n",map {'#'.$_} split /\n/,$note ) : undef;
                 push @v, $comment ? [ $value, $comment ] : $value;
             }
             push @section, $elt , \@v if @v;
@@ -332,7 +332,7 @@ With a dpkg file containing:
 
  Name: Foo
  Version: 1.2
- 
+
  # section comment
  Name: Bar
  # data comment
@@ -347,9 +347,13 @@ With a dpkg file containing:
 Parse the file with:
 
  package MyParser ;
+
  use strict;
  use warnings;
 
+ use 5.20.1;
+
+ # DpkgSyntax uses Log4perl, so we must initialise this module
  use Log::Log4perl qw(:easy);
  Log::Log4perl->easy_init($WARN);
 
@@ -358,18 +362,18 @@ Parse the file with:
  with 'Config::Model::Backend::DpkgSyntax';
 
  package main ;
- use IO::File;
- use Data::Dumper;
+ use Path::Tiny;
+ use YAML::XS;
 
- my $file = 'examples/dpkg-test'; # replace with any file name
- my $fh = IO::File->new();
- $fh->open("<  $file");
+ # load control file
+ my $file = path('dpkg-test');
 
+ # create your parser
  my $parser = MyParser->new() ;
- my $data = $parser->parse_dpkg_file($file, $fh, 'yes', 1);
- $fh->close;
- 
- print Dumper $data;
+
+ # convert control file data in a Perl data structure
+ # documented in Synopsis
+ my $data = $parser->parse_dpkg_file($file, 'yes', 1);
 
 Data contains:
 
@@ -408,46 +412,44 @@ Data contains:
 To write Dpkg file back:
 
  package MyParser ;
- 
+
  use strict;
  use warnings;
- 
+
  use 5.20.1;
- 
+
+ # DpkgSyntax uses Log4perl, so we must initialise this module
  use Log::Log4perl qw(:easy);
  Log::Log4perl->easy_init($WARN);
- 
+
  # load role
  use Mouse ;
  with 'Config::Model::Backend::DpkgSyntax';
- 
+
  package main ;
- use IO::File;
- use Data::Dumper;
- 
- # note: the structure is different compared to the one returned by
- # the parser (no line number)
+ use Path::Tiny;
+
  my $data = [
-    [ '# section comment', qw/Name Foo/, '# data comment', qw/Version 1.2/ ],
-    [
-        qw/Name Bar Version 1.3/ ,
-        Files => [qw/file1/, [ 'file2' , '# inline comment'] ] ,
-        Description => "A very\n\nlong description"
-    ]
+     [
+         '# section comment', qw/Name Foo/,
+         '# data comment', qw/Version 1.2/
+     ],
+     [
+         qw/Name Bar Version 1.3/ ,
+         Files => [qw/file1/, [ 'file2' , '# inline comment'] ] ,
+         Description => "A very\n\nlong description"
+     ]
  ];
- 
+
  my $parser = MyParser->new() ;
- 
- my $fhw = IO::File->new ;
- $fhw -> open ( 'examples/dpkg-new' ,'>',"," ) ;
- 
- $parser->write_dpkg_file($fhw,$data) ;
- $fhw->close;
+
+ # print control file content
+ say $parser->write_dpkg_file($data) ;
 
 
 =head1 DESCRIPTION
 
-This module is a Moose role to read and write dpkg control files. 
+This module is a Moose role to read and write dpkg control files.
 
 Debian control file are read and transformed in a structure
 matching the control file. The top level list of a list of section.
@@ -460,9 +462,9 @@ syntax idiosyncrasies. The leading white space is removed and the
 single dot is transformed in to a "\n". These characters are restored
 when the file is written back.
 
-Last not but not least, this module could re-used outside of
+Last not but not least, this module can be re-used outside of
 C<Config::Model> with some small modifications in exception
-handing. Ask the author if you want this module shipped in its own
+handling. Ask the author if you want this module shipped in its own
 distribution.
 
 =head1
@@ -474,7 +476,7 @@ Parameters: C<( file_path, file_handle, [ check, [ comment_allowed ]] )>
 Read a control file from C<file_handle> and returns a nested list (or
 a list ref) containing data from the file.
 
-See sysnopsis for the returned structure.
+See synopsis for the returned structure.
 
 C<check> is C<yes>, C<skip> or C<no> (default C<yes>).
  C<comment_allowed> is boolean (default 0)
