@@ -8,7 +8,9 @@ return [
       {
         'description' => 'Additional user-defined fields
 
-Fields in the main source control information file with names starting X, followed by one or more of the letters BCS and a hyphen -, will be copied to the output files. Only the part of the field name after the hyphen will be used in the output file. Where the letter B is used the field will appear in binary package control files, where the letter S is used in Debian source control files and where C is used in upload control (.changes) files.
+Fields in the main source control information file with names starting X, followed by one or more of the letters BCS and a hyphen -, will be copied to the output files.
+Only the part of the field name after the hyphen will be used in the output file. Where the letter B is used the field will appear in binary package control files, where the letter S
+is used in Debian source control files and where C is used in upload control (.changes) files.
 
 For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debian-policy/#document-ch-controlfields>',
         'summary' => 'User defined field',
@@ -59,7 +61,8 @@ $ret;',
         },
         'description' => 'The package maintainer\'s name and email address. The name must come first, then the email address inside angle brackets <> (in RFC822 format).
 
-If the maintainer\'s name contains a full stop then the whole field will not work directly as an email address due to a misfeature in the syntax specified in RFC822; a program using this field as an address must check for this and correct the problem if necessary (for example by putting the name in round brackets and moving it to the end, and bringing the email address forward). ',
+If the maintainer\'s name contains a full stop then the whole field will not work directly as an email address due to a misfeature in the syntax specified in RFC822;
+a program using this field as an address must check for this and correct the problem if necessary (for example by putting the name in round brackets and moving it to the end, and bringing the email address forward). ',
         'summary' => 'package maintainer\'s name and email address',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -94,7 +97,8 @@ to know what changes came with a new policy version number and apply the require
           'current' => {
             'code' => '$self->compare_with_last_version($_) == -1;',
             'fix' => '$_ = $self->_fetch_std; # restore default value',
-            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package
+to upgrade it from standard version \'$_\' to \'$std_value\'.
 '
           },
           'old_lintian' => {
@@ -111,7 +115,7 @@ to know what changes came with a new policy version number and apply the require
 grouped further into sections to simplify handling.
 
 The archive area and section for each package should be specified in
-the package\'s Section control record (see 
+the package\'s Section control record (see
 L<Section 5.6.5|https://www.debian.org/doc/debian-policy/#section>).
 However, the maintainer of the Debian archive may override
 this selection to ensure the consistency of the Debian
@@ -119,7 +123,7 @@ distribution. The Section field should be of the form:
 
 '.'=over
 
-'.'=item * 
+'.'=item *
 
 section if the package is in the main archive area,
 
@@ -199,8 +203,8 @@ $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
       'XS-Autobuild',
       {
         'default' => '0',
-        'description' => 'Read the full description from 
-L<section 5.10.5|https://www.debian.org/doc/manuals/developers-reference/pkgs.html#non-free-buildd> 
+        'description' => 'Read the full description from
+L<section 5.10.5|https://www.debian.org/doc/manuals/developers-reference/pkgs.html#non-free-buildd>
 in Debian developer reference.',
         'level' => 'hidden',
         'summary' => 'Allow automatic build of non-free or contrib package',
@@ -233,11 +237,19 @@ in Debian developer reference.',
         ],
         'default' => 'optional',
         'help' => {
-          'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful if you already know what they are or have specialized requirements (such as packages containing only detached debugging symbols).',
-          'important' => 'Important programs, including those which one would expect to find on any Unix-like system. If the expectation is that an experienced Unix person who found it missing would say "What on earth is going on, where is foo?", it must be an important package.[5] Other packages without which the system will not run well or be usable must also have priority important. This does not include Emacs, the X Window System, TeX or any other large applications. The important packages are just a bare minimum of commonly-expected and necessary tools.',
-          'optional' => '(In a sense everything that isn\'t required is optional, but that\'s not what is meant here.) This is all the software that you might reasonably want to install if you didn\'t know what it was and don\'t have specialized requirements. This is a much larger system and includes the X Window System, a full TeX distribution, and many applications. Note that optional packages should not conflict with each other. ',
-          'required' => 'Packages which are necessary for the proper functioning of the system (usually, this means that dpkg functionality depends on these packages). Removing a required package may cause your system to become totally broken and you may not even be able to use dpkg to put things back, so only do so if you know what you are doing. Systems with only the required packages are probably unusable, but they do have enough functionality to allow the sysadmin to boot and install more software. ',
-          'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t select anything else. It doesn\'t include many large applications. '
+            'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful
+if you already know what they are or have specialized requirements (such as packages containing only detached debugging symbols).',
+            'important' => 'Important programs, including those which one would expect to find on any Unix-like system. If the expectation is that an experienced Unix person
+who found it missing would say "What on earth is going on, where is foo?", it must be an important package.[5] Other packages without which the system will not run well or
+be usable must also have priority important. This does not include Emacs, the X Window System, TeX or any other large applications. The important packages are just a bare minimum of commonly-expected and necessary tools.',
+            'optional' => '(In a sense everything that isn\'t required is optional, but that\'s not what is meant here.) This is all the software that you might reasonably
+want to install if you didn\'t know what it was and don\'t have specialized requirements. This is a much larger system and includes the X Window System, a full TeX distribution, and many applications.
+Note that optional packages should not conflict with each other. ',
+            'required' => 'Packages which are necessary for the proper functioning of the system (usually, this means that dpkg functionality depends on these packages).
+Removing a required package may cause your system to become totally broken and you may not even be able to use dpkg to put things back, so only do so if you know what you are doing.
+Systems with only the required packages are probably unusable, but they do have enough functionality to allow the sysadmin to boot and install more software. ',
+            'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t
+select anything else. It doesn\'t include many large applications. '
         },
         'type' => 'leaf',
         'value_type' => 'enum',
@@ -329,7 +341,7 @@ for more details.
           'value_type' => 'uniline'
         },
         'class' => 'Config::Model::Dpkg::DependencyList',
-        'description' => 'Same as Build-Depends, but these packages are only needed when building the architecture dependent packages. The Build-Depends are also installed in this case. 
+        'description' => 'Same as Build-Depends, but these packages are only needed when building the architecture dependent packages. The Build-Depends are also installed in this case.
 
 See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb-src-control.5.en.html> for details',
         'duplicates' => 'warn',
@@ -390,7 +402,7 @@ See L<build target|https://www.debian.org/doc/debian-policy/#relationships-betwe
 
 On the other hand, the list of packages that must B<not> be installed to build architecture-independent binaries ("Architecture: all") should be listed in "Build-Conflicts-Indep" field.
 
-Including a dependency in this list has the same effect as including it in both Build-Conflicts-Arch and Build-Conflicts-Indep, with the additional effect of being used for source-only builds. 
+Including a dependency in this list has the same effect as including it in both Build-Conflicts-Arch and Build-Conflicts-Indep, with the additional effect of being used for source-only builds.
 
 See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb-src-control.5.en.html> for details.',
         'duplicates' => 'warn',
@@ -404,7 +416,7 @@ See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb
           'value_type' => 'uniline'
         },
         'class' => 'Config::Model::Dpkg::DependencyList',
-        'description' => 'List of packages that must be missing (i.e. B<not> installed) to build archictecture dependent binaries 
+        'description' => 'List of packages that must be missing (i.e. B<not> installed) to build archictecture dependent binaries
 
 See L<deb-src-control man page|https://manpages.debian.org/unstable/dpkg-dev/deb-src-control.5.en.html> for details.',
         'duplicates' => 'warn',
@@ -436,7 +448,8 @@ Note that packages not wanted during "clean" phase must be declared in "Build-Co
           'value_type' => 'uniline'
         },
         'class' => 'Config::Model::Dpkg::DependencyList',
-        'description' => ' Some binary packages incorporate parts of other packages when built but do not have to depend on those packages. Examples include linking with static libraries or incorporating source code from another package during the build. In this case, the source packages of those other packages are a required part of the complete source (the binary package is not reproducible without them).
+        'description' => ' Some binary packages incorporate parts of other packages when built but do not have to depend on those packages. Examples include linking with static libraries
+or incorporating source code from another package during the build. In this case, the source packages of those other packages are a required part of the complete source (the binary package is not reproducible without them).
 
 A Built-Using field must list the corresponding source package for any such binary package incorporated during the build, including an B<exactly equal> ("=") version relation on the version that was used to build that binary package[57].
 
@@ -490,9 +503,14 @@ The information is meant to be useful for the final user, willing to browse the
       },
       'Vcs-Arch',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
+mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic
+and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an
+anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -506,9 +524,15 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Vcs-Bzr',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
+mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package.
+To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead
+of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -522,9 +546,14 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Vcs-Cvs',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
+mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be
+version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -538,9 +567,14 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Vcs-Darcs',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
+It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package.
+To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -566,9 +600,13 @@ The information is meant to be useful for a user knowledgeable in the given Vers
             'pkgname' => '- Source'
           }
         },
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be
+version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -591,9 +629,14 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Vcs-Hg',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
+It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better
+be version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -607,18 +650,28 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Vcs-Mtn',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
+It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package.
+To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'Vcs-Svn',
       {
-        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package, if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
+          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
+It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
-The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources. Other uses of this information might include automatic building of the latest VCS version of the given package. To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept). Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
+The information is meant to be useful for a user knowledgeable in the given Version Control System and willing to build the current version of a package from the VCS sources.
+Other uses of this information might include automatic building of the latest VCS version of the given package.
+To this end the location pointed to by the field should better be version agnostic and point to the main branch (for VCSs supporting such a concept).
+Also, the location pointed to should be accessible to the final user; fulfilling this requirement might imply pointing to an anonymous access of the repository instead of pointing to an SSH-accessible version of the same. ',
         'summary' => 'URL of the VCS repository',
         'type' => 'leaf',
         'value_type' => 'uniline',
@@ -632,7 +685,8 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'DM-Upload-Allowed',
       {
-        'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.  For more information see the "Debian Maintainer" page at the Debian Wiki - https://wiki.debian.org/DebianMaintainer',
+          'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.
+For more information see the "Debian Maintainer" page at the Debian Wiki - https://wiki.debian.org/DebianMaintainer',
         'match' => 'yes',
         'status' => 'deprecated',
         'summary' => 'The package may be uploaded by a Debian Maintainer',
@@ -646,12 +700,16 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       },
       'Rules-Requires-Root',
       {
-        'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command. This command allows the debian/rules target to run particular subcommands under (fake)root. Can be \'no\', \'binary-targets\' (default)), or a space separated list of keywords containing a forward slash (e.g. "/").
+          'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command.
+This command allows the debian/rules target to run particular subcommands under (fake)root. Can be \'no\', \'binary-targets\' (default)), or a space separated list of keywords containing a forward slash (e.g. "/").
 
 For details, see L<section 5.6.31.2 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html#rules-requires-root>',
         'help' => {
-          '.+/' => 'Space separated list of keywords. These keywords must always contain a forward slash, which sets them apart from the other possible values of Rules-Requires-Root. When this list is provided, the builder must provide a gain root command (as defined in debian/rules and Rules-Requires-Root) or pretend that the value was set to binary-targets, and both the builder and the package’s debian/rules script must downgrade accordingly.',
-          'binary-targets' => '(Default) Declares that the package will need the root (or fakeroot) when either of the binary, binary-arch or binary-indep targets are called. This is how every tool behaved before this field was defined.',
+            '.+/' => 'Space separated list of keywords. These keywords must always contain a forward slash, which sets them apart from the other possible values of Rules-Requires-Root.
+When this list is provided, the builder must provide a gain root command (as defined in debian/rules and Rules-Requires-Root) or pretend that the value was set to binary-targets,
+and both the builder and the package’s debian/rules script must downgrade accordingly.',
+            'binary-targets' => '(Default) Declares that the package will need the root (or fakeroot) when either of the binary, binary-arch or binary-indep targets are called.
+This is how every tool behaved before this field was defined.',
           'no' => 'Declares that neither root nor fakeroot is required. Package builders (e.g. dpkg-buildpackage) may choose to invoke any target in debian/rules with an unprivileged user.'
         },
         'summary' => 'Defines if access to root (or fakeroot) is required during build.',
@@ -671,17 +729,19 @@ For details, see L<section 5.6.31.2 of Debian policy|https://www.debian.org/doc/
       },
       'X-Python-Version',
       {
-        'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.  When not specified, they default to all currently supported Python (or Python 3) versions. For more detail, See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
+          'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.
+When not specified, they default to all currently supported Python (or Python 3) versions. For more detail,
+See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'migrate_from' => {
           'formula' => 'my $old = $xspython ;
 my $new ;
 if ($old =~ /,/) {
    # list of versions
-   my @list = sort split /\\s*,\\s*/, $old ; 
+   my @list = sort split /\\s*,\\s*/, $old ;
    $new = ">= ". (shift @list) . ", << " .  (pop @list) ;
 }
 elsif ($old =~ /-/) {
-   my @list = sort grep { $_ ;} split /\\s*-\\s*/, $old ; 
+   my @list = sort grep { $_ ;} split /\\s*-\\s*/, $old ;
    $new = ">= ". shift @list ;
    $new .= ", << ". pop @list if @list ;
 }
@@ -701,7 +761,8 @@ $new ;',
       },
       'X-Python3-Version',
       {
-        'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail, See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
+          'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail,
+See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'summary' => 'supported versions of Python3 ',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -732,4 +793,3 @@ supported by the library',
   }
 ]
 ;
-
