@@ -70,8 +70,12 @@ There is currently no way to specify this hint on a per-test basis; but in any c
           'needs-root' => 'The test script must be run as root.',
           'rw-build-tree' => 'The test(s) needs write access to the built source tree (so it may need to be copied first). Even with this restriction, the test is not allowed to make any change to the built source tree which (i) isn\'t cleaned up by debian/rules clean, (ii) affects the future results of any test, or (iii) affects binary packages produced by the build tree in the future.',
           'skip-not-installable' => 'This test might have test dependencies that can\'t be fulfilled on all architectures. Therefore, when apt-get installs the dependencies, it will fail. Don\'t treat this as a test failure, but instead treat it as if the test was skipped.',
-          'skippable' => 'The test might need to be skipped for reasons that cannot be described by an existing restriction such as isolation-machine or breaks-testbed, but must instead be detected at runtime. If the test exits with status 77 (a convention borrowed from Automake), it will be treated as though it had been skipped. If it exits with any other status, its success or failure will be derived from the exit status and stderr as usual. Test authors must be careful to ensure that `kippable tests never exit with status 77 for reasons that should be treated as a failure.',
-          'superficial' => 'The test does not provide significant test coverage, so if it passes, that does not necessarily mean that the package under test is actually functional. If a superficial test fails, it will be treated like any other failing test, but if it succeeds, this is only a weak indication of success. Continuous integration systems should treat a package where all non-superficial tests are skipped as equivalent to a package where all tests are skipped.
+          'skippable' => 'The test might need to be skipped for reasons that cannot be described by an existing restriction such as isolation-machine or breaks-testbed, but must instead be detected at runtime.
+If the test exits with status 77 (a convention borrowed from Automake), it will be treated as though it had been skipped.
+If it exits with any other status, its success or failure will be derived from the exit status and stderr as usual.
+Test authors must be careful to ensure that `kippable tests never exit with status 77 for reasons that should be treated as a failure.',
+          'superficial' => 'The test does not provide significant test coverage, so if it passes, that does not necessarily mean that the package under test is actually functional.
+If a superficial test fails, it will be treated like any other failing test, but if it succeeds, this is only a weak indication of success. Continuous integration systems should treat a package where all non-superficial tests are skipped as equivalent to a package where all tests are skipped.
 
 For example, a C library might have a superficial test that simply compiles, links and executes a "hello world" program against the library under test but does not attempt to make use of the library\'s functionality, while a Python or Perl library might have a superficial test that runs "import foo" or "require Foo;" but does not attempt to use the library beyond that.'
         },
