@@ -218,10 +218,10 @@ sub _get_data_from_files  ( %args ) {
         $pipe->close or die $! ? "Error closing licensecheck pipe: $!\n"
                                : "Exit status ".$?." $cmd\n";
     }
-    return _trim_lines (\@lines, \%regexps);
+    return _parse_lines (\@lines, \%regexps);
 }
 
-sub _trim_lines ($lines, $regexps) {
+sub _parse_lines ($lines, $regexps) {
     my @kept_lines;
     my @skipped;
     foreach my $line (sort $lines->@*) {
@@ -784,7 +784,7 @@ sub __find_main_license_id ($copyrights_by_id, $main_info) {
 
         # check whether the new copyright/license already exists
         # before creating a new one
-        for (my $idx = 0; $idx < $#$copyrights_by_id; $idx++) {
+        for (my $idx = 0; $idx < $copyrights_by_id->@*; $idx++) {
             if (Compare($copyrights_by_id->[$idx], $new_data)) {
                 return $idx;
             }
