@@ -86,7 +86,8 @@ my @tests = (
             'package-scripts:t0 prerm' => qr/dummy prerm/,
             'package-scripts:t0/amd64 postrm' => qr/dummy postrm script for amd64/,
             'package-scripts:./amd64 preinst' => qr/dummy preinst script for amd64/,
-            'examples:t0 content:0' => 'examples/'
+            'examples:t0 content:0' => 'examples/',
+            'install:t0.docs content:0' => 'README.*',
         },
         log4perl_load_warnings => [[
             User =>  map {(warn => $_)} qr/source Standards-Version/, qr/compat/, (qr/debhelper/) x 2 , qr/Dual dependency/
